@@ -34,16 +34,8 @@
 #include <config.h>
 #endif
 
-#include <rcsc/math_util.h>
-#include <rcsc/soccer_math.h>
-#include <rcsc/geom/ray_2d.h>
-#include <rcsc/geom/rect_2d.h>
-#include <rcsc/geom/sector_2d.h>
-#include <rcsc/param/server_param.h>
-
-#include <rcsc/player/player_agent.h>
-#include <rcsc/player/debug_client.h>
-#include <rcsc/player/logger.h>
+#include "body_dribble.h"
+#include "intention_dribble.h"
 
 #include "basic_actions.h"
 #include "body_go_to_point.h"
@@ -53,8 +45,15 @@
 #include "body_stop_ball.h"
 #include "neck_scan_field.h"
 
-#include "intention_dribble.h"
-#include "body_dribble.h"
+#include <rcsc/player/player_agent.h>
+#include <rcsc/player/debug_client.h>
+#include <rcsc/player/logger.h>
+#include <rcsc/param/server_param.h>
+#include <rcsc/geom/ray_2d.h>
+#include <rcsc/geom/rect_2d.h>
+#include <rcsc/geom/sector_2d.h>
+#include <rcsc/soccer_math.h>
+#include <rcsc/math_util.h>
 
 namespace rcsc {
 
@@ -673,8 +672,7 @@ Body_Dribble::doKickDashes( PlayerAgent * agent,
 #endif
             used_power *= accel_mag / max_accel_mag;
         }
-        Vector2D dash_accel( Vector2D::POLE,
-                             accel_mag, accel_angle );
+        Vector2D dash_accel = Vector2D::polar2vector( accel_mag, accel_angle );
         my_vel += dash_accel;
         my_pos += my_vel;
 
@@ -797,8 +795,8 @@ Body_Dribble::doKickDashes( PlayerAgent * agent,
         }
     }
 
-    const Vector2D next_ball_rel( Vector2D::POLE,
-                                  control_dist, keep_global_angle );
+    const Vector2D next_ball_rel
+        = Vector2D::polar2vector( control_dist, keep_global_angle );
     Vector2D next_ctrl_ball_pos = wm.self().pos() + my_pos + next_ball_rel;
     dlog.addText( Logger::DRIBBLE,
                   "%s:%d: KickDashes. next_ball_rel=(%.2f, %.2f) global(%.2f %.2f)"
@@ -1232,9 +1230,8 @@ Body_Dribble::doDodge( PlayerAgent * agent,
         = getAvoidAngle( agent,
                          ( target_point - wm.self().pos() ).th() );
 
-    const Vector2D new_target_rel( Vector2D::POLE,
-                                   new_target_dist,
-                                   avoid_angle );
+    const Vector2D new_target_rel
+        = Vector2D::polar2vector( new_target_dist, avoid_angle );
     Vector2D new_target
         = wm.self().pos()
         + new_target_rel;
@@ -1376,9 +1373,8 @@ Body_Dribble::doAvoidKick( PlayerAgent * agent,
 
     const double ball_move_radius = 2.0;
 
-    const Vector2D target_rel_point( Vector2D::POLE,
-                                     ball_move_radius,
-                                     avoid_angle );
+    const Vector2D target_rel_point
+        = Vector2D::polar2vector( ball_move_radius, avoid_angle );
 
     // my max turnable moment with current speed
     const double next_turnable
@@ -1418,9 +1414,9 @@ Body_Dribble::doAvoidKick( PlayerAgent * agent,
         ball_first_speed = 0.3;
     }
 
-    Vector2D required_first_vel( Vector2D::POLE,
-                                 ball_first_speed,
-                                 ( target_rel_point - wm.ball().rpos() ).th() );
+    Vector2D required_first_vel
+        = Vector2D::polar2vector( ball_first_speed,
+                                  ( target_rel_point - wm.ball().rpos() ).th() );
     Vector2D required_accel = required_first_vel - wm.ball().vel();
     double required_kick_power = required_accel.r() / wm.self().kickRate();
 
@@ -1577,8 +1573,8 @@ Body_Dribble::canKickAfterDash( const PlayerAgent * agent,
     {
         *dash_power *= accel_mag / max_accel_mag;
     }
-    Vector2D dash_accel( Vector2D::POLE,
-                         accel_mag, accel_angle );
+    Vector2D dash_accel
+        = Vector2D::polar2vector( accel_mag, accel_angle );
 
     Vector2D ball_pos = wm.ball().rpos();
     Vector2D ball_vel = wm.ball().vel();
@@ -1699,7 +1695,7 @@ Body_Dribble::getAvoidAngle( const PlayerAgent * agent,
         for ( int i = 0; i < 2; i++ )
         {
             const Vector2D sub_target
-                = wm.self().pos() 
+                = wm.self().pos()
                 + Vector2D::polar2vector( avoid_radius,
                                           new_target_angle );
 
@@ -1789,6 +1785,12 @@ Body_Dribble::getAvoidAngle( const PlayerAgent * agent,
             continue;
         }
 
+        if ( sub_target.x < 30.0
+             && sub_target.x < wm.self().pos().x - 2.0 )
+        {
+            continue;
+        }
+
         bool success = true;
         for ( PlayerPtrCont::const_iterator it = opps.begin();
               it != opps_end;
@@ -1850,14 +1852,17 @@ Body_Dribble::getAvoidAngle( const PlayerAgent * agent,
 
     double best_score = 10000.0;
     Vector2D best_target = wm.self().pos();
-    best_target.x += 2.0;
 
-    for ( double x_i = - 8.0; x_i < 8.5; x_i += 1.0 )
+    double x_i = 30.0 - wm.self().pos().x;
+    if ( x_i > 0.0 ) x_i = 0.0;
+    if ( x_i < -8.0 ) x_i = -8.0;
+
+    for ( ; x_i < 8.5; x_i += 1.0 )
     {
         for ( double y_i = - 8.0; y_i < 8.5; y_i += 1.0 )
         {
             Vector2D candidate = wm.self().pos();
-            candidate.add(x_i, y_i);
+            candidate.add( x_i, y_i );
 
             if ( candidate.absX() > ServerParam::i().pitchHalfLength() - 1.0
                  || candidate.absY() > ServerParam::i().pitchHalfWidth() - 1.0 )
