@@ -33,20 +33,18 @@
 #include <config.h>
 #endif
 
-#include <rcsc/math_util.h>
-#include <rcsc/soccer_math.h>
-
-#include <rcsc/param/server_param.h>
-
-#include <rcsc/player/logger.h>
-#include <rcsc/player/player_agent.h>
-#include <rcsc/player/intercept_table.h>
-#include <rcsc/player/debug_client.h>
+#include "body_intercept.h"
 
 #include "basic_actions.h"
 #include "body_go_to_point.h"
 
-#include "body_intercept.h"
+#include <rcsc/player/logger.h>
+#include <rcsc/player/intercept_table.h>
+#include <rcsc/player/player_agent.h>
+#include <rcsc/player/debug_client.h>
+#include <rcsc/param/server_param.h>
+#include <rcsc/soccer_math.h>
+#include <rcsc/math_util.h>
 
 namespace rcsc {
 
@@ -69,11 +67,11 @@ Body_Intercept::execute( PlayerAgent * agent )
         return true;;
     }
 
-    const InterceptTable * table = wm.getInterceptTable();
+    const InterceptTable * table = wm.interceptTable();
     Vector2D reach_point;
 
     /////////////////////////////////////////////
-    if ( table->getSelfReachCycle() > 100 )
+    if ( table->selfReachCycle() > 100 )
     {
         reach_point = wm.ball().inertiaFinalPoint();
         agent->debugClient().setTarget( reach_point );
@@ -91,20 +89,20 @@ Body_Intercept::execute( PlayerAgent * agent )
     }
 
     /////////////////////////////////////////////
-    InterceptInfo best_point = getBestPoint( wm, table );
+    InterceptInfo best_intercept = getBestPoint( wm, table );
 
     dlog.addText( Logger::INTERCEPT,
                   "%s: solution size= %d. selected best cycle is %d"
                   " (turn:%d + dash:%d)"
                   ,__FILE__,
-                  table->getSelfCache().size(),
-                  best_point.getReachCycle(),
-                  best_point.getTurnCycle(), best_point.getDashCycle() );
+                  table->selfCache().size(),
+                  best_intercept.reachCycle(),
+                  best_intercept.turnCycle(), best_intercept.dashCycle() );
 
-    reach_point = wm.ball().inertiaPoint( best_point.getReachCycle() );
+    reach_point = wm.ball().inertiaPoint( best_intercept.reachCycle() );
     agent->debugClient().setTarget( reach_point );
 
-    if ( best_point.getDashCycle() == 0 )
+    if ( best_intercept.dashCycle() == 0 )
     {
         dlog.addText( Logger::INTERCEPT,
                       "%s: can get the ball only by inertia move. Turn!"
@@ -116,14 +114,14 @@ Body_Intercept::execute( PlayerAgent * agent )
     }
 
     /////////////////////////////////////////////
-    if ( best_point.getTurnCycle() > 0 )
+    if ( best_intercept.turnCycle() > 0 )
     {
         Vector2D my_inertia
             = wm.self().playerType().inertiaPoint( wm.self().pos(),
                                                    wm.self().vel(),
-                                                   best_point.getReachCycle() );
+                                                   best_intercept.reachCycle() );
         AngleDeg target_angle = ( reach_point - my_inertia ).th();
-        if ( best_point.getPower() < 0.0 )
+        if ( best_intercept.dashPower() < 0.0 )
         {
             // back dash
             target_angle -= 180.0;
@@ -132,12 +130,12 @@ Body_Intercept::execute( PlayerAgent * agent )
         dlog.addText( Logger::INTERCEPT,
                       "%s:%d: turn.first.%s target_body_angle = %.1f"
                       ,__FILE__, __LINE__,
-                      ( best_point.getPower() < 0.0 ? "BackMode" : "" ),
+                      ( best_intercept.dashPower() < 0.0 ? "BackMode" : "" ),
                       target_angle.degree() );
         agent->debugClient().addMessage( "InterceptTurn%d(%d/%d)",
-                                         best_point.getReachCycle(),
-                                         best_point.getTurnCycle(),
-                                         best_point.getDashCycle() );
+                                         best_intercept.reachCycle(),
+                                         best_intercept.turnCycle(),
+                                         best_intercept.dashCycle() );
 
         return agent->doTurn( target_angle - wm.self().body() );
     }
@@ -146,18 +144,18 @@ Body_Intercept::execute( PlayerAgent * agent )
     dlog.addText( Logger::INTERCEPT,
                   "%s:%d: try dash. power=%.1f  pos=(%.2f, %.2f)"
                   ,__FILE__, __LINE__,
-                  best_point.getPower(),
+                  best_intercept.dashPower(),
                   reach_point.x, reach_point.y );
-    if ( doWaitTurn( agent, best_point ) )
+    if ( doWaitTurn( agent, best_intercept ) )
     {
         return true;
     }
 
     if ( M_save_recovery
          && ( wm.self().stamina()
-              - ( best_point.getPower() * ( best_point.getPower() > 0.0
-                                            ? 1.0
-                                            : -2.0 )
+              - ( best_intercept.dashPower() * ( best_intercept.dashPower() > 0.0
+                                                 ? 1.0
+                                                 : -2.0 )
                   )
               < ServerParam::i().recoverDecThrValue() + 1.0 )
          )
@@ -170,11 +168,11 @@ Body_Intercept::execute( PlayerAgent * agent )
         return false;
     }
 
-    //return agent->doDash( best_point.getPower() );
+    //return agent->doDash( best_intercept.dashPower() );
     return doInertiaDash( agent,
                           reach_point,
-                          best_point.getPower(),
-                          best_point.getReachCycle() );
+                          best_intercept.dashPower(),
+                          best_intercept.reachCycle() );
 }
 
 /*-------------------------------------------------------------------*/
@@ -216,11 +214,12 @@ Body_Intercept::getBestPoint( const WorldModel & wm,
                               const InterceptTable * table ) const
 {
 
-    const std::vector< InterceptInfo > & cache = table->getSelfCache();
+    const std::vector< InterceptInfo > & cache = table->selfCache();
 
-    const int opp_cycle = table->getOpponentReachCycle();
+    const int opp_cycle = table->opponentReachCycle();
 
     std::size_t best_idx = 1000;
+    double max_x = -1000.0;
     double min_dist2 = 40000.0;
     double turn0_min_dist2 = 40000.0;
 
@@ -232,22 +231,28 @@ Body_Intercept::getBestPoint( const WorldModel & wm,
         {
             continue;
         }
-        int cycle = cache[i].getReachCycle();
+
+        int cycle = cache[i].reachCycle();
         const Vector2D ball_pos = wm.ball().inertiaPoint( cycle );
+
         if ( ball_pos.absX() > ServerParam::i().pitchHalfLength() - 1.0
              || ball_pos.absY() > ServerParam::i().pitchHalfWidth() - 1.0 )
         {
             continue;
         }
+
         const Vector2D ball_vel = wm.ball().vel() * std::pow( ServerParam::i().ballDecay(),
-                                                                 cycle );
-        if ( ball_vel.r() < 0.5 )
+                                                              cycle );
+
+        bool attacker = false;
+        if ( ball_vel.x > 0.5
+             && ball_pos.x > wm.offsideLineX() - 5.0 )
         {
-            continue;
+            attacker = true;
         }
 
         // can get the ball without turn
-        if ( cache[i].getTurnCycle() == 0
+        if ( cache[i].turnCycle() == 0
              && cycle <= opp_cycle )
         {
             if ( best_idx > 100 && opp_cycle > 3 )
@@ -263,19 +268,52 @@ Body_Intercept::getBestPoint( const WorldModel & wm,
                 continue;
             }
         }
-        // opponent is faster
-        if ( cycle >= opp_cycle - 3 )
+
+        // opponent check
+
+        int opp_buf = 3;
+
+        if ( attacker )
+        {
+            opp_buf = -1;
+        }
+
+        if ( cycle >= opp_cycle - opp_buf )
         {
             continue;
         }
+
+        if ( attacker )
+        {
+            if ( best_idx < 100 )
+            {
+                if ( ball_vel.r() < 0.7
+                     || ball_pos.x > 47.0
+                     || std::fabs( ball_pos.y - wm.self().pos().y ) > 10.0
+                     )
+                {
+                    continue;
+                }
+            }
+
+            if ( ball_pos.x > max_x )
+            {
+                max_x = ball_pos.x;
+                best_idx = i;
+            }
+
+            continue;
+        }
+
         // can get the ball only by inertia move
-        if ( cache[i].getDashCycle() == 0 )
+        if ( cache[i].dashCycle() == 0 )
         {
             best_idx = i;
             break;
         }
+
         // no turn is recommended
-        if ( cache[i].getTurnCycle() == 0 )
+        if ( cache[i].turnCycle() == 0 )
         {
             best_idx = i;
             break;
@@ -332,15 +370,20 @@ bool
 Body_Intercept::doWaitTurn( PlayerAgent * agent,
                             const InterceptInfo & info )
 {
-    const int reach_cycle = info.getReachCycle();
+    const int reach_cycle = info.reachCycle();
+    const WorldModel & wm = agent->world();
+
+    Vector2D ball_pos = wm.ball().inertiaPoint( reach_cycle );
+
+    const int max_wait_cycle = ( ball_pos.x > 10.0
+                                 ? 8
+                                 : 3 );
     if ( reach_cycle == 1
-         || 4 <= reach_cycle )
+         || max_wait_cycle <= reach_cycle )
     {
         return false;
     }
 
-    const WorldModel & wm = agent->world();
-
     {
         const PlayerObject * opp = wm.getOpponentNearestToSelf( 5 );
         if ( opp && opp->distFromSelf() < 3.0 )
@@ -352,11 +395,11 @@ Body_Intercept::doWaitTurn( PlayerAgent * agent,
         }
     }
 
-    Vector2D ball_pos = wm.ball().inertiaPoint( reach_cycle );
     Vector2D my_inertia = wm.self().playerType().inertiaPoint( wm.self().pos(),
                                                                wm.self().vel(),
                                                                reach_cycle );
     const double inertia_dist = my_inertia.dist( ball_pos );
+    /*
     if ( inertia_dist < ( wm.self().playerType().playerSize()
                           + ServerParam::i().ballSize()
                           + 0.15 ) )
@@ -367,10 +410,11 @@ Body_Intercept::doWaitTurn( PlayerAgent * agent,
                       inertia_dist );
         return false;
     }
+    */
 
-    if ( inertia_dist < wm.self().kickableArea() - 0.3 )
+    if ( inertia_dist < wm.self().kickableArea() - 0.3 + (0.1*reach_cycle) )
     {
-        Vector2D face_point( 50.5, wm.self().pos().y * 0.75 );
+        Vector2D face_point( 50.5, wm.self().pos().y * 0.9 );
 
         Body_TurnToPoint( face_point ).execute( agent );
         dlog.addText( Logger::INTERCEPT,
@@ -382,11 +426,28 @@ Body_Intercept::doWaitTurn( PlayerAgent * agent,
 
     Vector2D target_rel = ball_pos - my_inertia;
     AngleDeg accel_angle = wm.self().body();
-    if ( info.getPower() < 0.0 )
+
+    if ( info.dashPower() < 0.0 )
     {
         accel_angle += 180.0;
     }
+
     target_rel.rotate( - accel_angle );
+    if ( reach_cycle >= 3 )
+    {
+        if ( target_rel.x > 0.0 )
+        {
+            target_rel.x -= 0.3;
+            if ( target_rel.x < 0.3 ) target_rel.x = 0.3;
+        }
+        else
+        {
+            target_rel.x += 0.3;
+            if ( target_rel.x > -0.3 ) target_rel.x = -0.3;
+        }
+
+    }
+
     double first_speed
         = calc_first_term_geom_series
         ( target_rel.x,
@@ -399,7 +460,7 @@ Body_Intercept::doWaitTurn( PlayerAgent * agent,
     Vector2D rel_vel = wm.self().vel().rotatedVector( - accel_angle );
     double required_accel = first_speed - rel_vel.x;
     double used_power = required_accel / wm.self().dashRate();
-    if ( info.getPower() < 0.0 ) used_power = -used_power;
+    if ( info.dashPower() < 0.0 ) used_power = -used_power;
 
     used_power = ServerParam::i().normalizePower( used_power );
 
@@ -417,7 +478,7 @@ Body_Intercept::doWaitTurn( PlayerAgent * agent,
     //          << " InterceptInertiaDist= "
     //          << my_inertia.dist( ball_pos )
     //          << " InertiaDash"
-    //          << " origPow="  << info.getPower()
+    //          << " origPow="  << info.dashPower()
     //          << " newPow=" << used_power
     //          << std::endl;
     agent->doDash( used_power );
