@@ -34,20 +34,19 @@
 #include <config.h>
 #endif
 
-#include <rcsc/math_util.h>
-#include <rcsc/soccer_math.h>
-#include <rcsc/geom/ray_2d.h>
-#include <rcsc/geom/circle_2d.h>
-#include <rcsc/param/server_param.h>
-
-#include <rcsc/player/logger.h>
-#include <rcsc/player/player_agent.h>
+#include "body_kick_two_step.h"
 
 #include "body_kick_one_step.h"
 #include "body_stop_ball.h"
 #include "body_kick_to_relative.h"
 
-#include "body_kick_two_step.h"
+#include <rcsc/player/logger.h>
+#include <rcsc/player/player_agent.h>
+#include <rcsc/param/server_param.h>
+#include <rcsc/geom/circle_2d.h>
+#include <rcsc/geom/ray_2d.h>
+#include <rcsc/soccer_math.h>
+#include <rcsc/math_util.h>
 
 namespace rcsc {
 
@@ -254,8 +253,8 @@ Body_KickTwoStep::simulate_one_kick( Vector2D * achieved_vel,
         = std::min( ServerParam::i().maxPower() * krate,
                     ServerParam::i().ballAccelMax() );
 
-    Vector2D required_vel( Vector2D::POLE,
-                           first_speed, ( target_rpos - ball_rpos ).th());
+    Vector2D required_vel
+        = Vector2D::polar2vector( first_speed, ( target_rpos - ball_rpos ).th() );
 
     // can NOT reach the target vel
     if ( ( required_vel - ball_vel ).r() > enable_acc ) // * 0.95 )
@@ -356,7 +355,7 @@ Body_KickTwoStep::simulate_two_kick( Vector2D * achieved_vel,
         Vector2D sol1, sol2;
         int num = next_kickable_circle.intersection( desired_ray, &sol1, &sol2 );
         //Vector2D require_vel( Vector2D::Invalid() );
-        Vector2D require_vel( Vector2D::INVALID );
+        Vector2D require_vel( Vector2D::INVALIDATED );
         if ( num == 1 )
         {
             // if ball point is not within next kicable area.
