@@ -30,12 +30,15 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
-#include <sstream>
-#include <algorithm>
-#include <iterator>
+#include "coach_agent.h"
+
+#include "coach_config.h"
+#include "coach_command.h"
+#include "global_visual_sensor.h"
+#include "global_world_model.h"
 
 #include <rcsc/param/server_param.h>
 #include <rcsc/param/player_param.h>
@@ -44,12 +47,7 @@
 #include <rcsc/param/conf_file_parser.h>
 #include <rcsc/param/cmd_line_parser.h>
 
-#include "coach_config.h"
-#include "coach_command.h"
-#include "global_visual_sensor.h"
-#include "global_world_model.h"
-
-#include "coach_agent.h"
+#include <sstream>
 
 namespace rcsc {
 
@@ -204,23 +202,19 @@ CoachAgent::visualSensor() const
 
 */
 bool
-CoachAgent::doInit( const int argc,
-                    const char * const * argv )
+CoachAgent::doInit( CmdLineParser & cmd_parser )
 {
     bool help = false;
     std::string coach_config_file;
 
     ParamMap system_param_map( "System options" );
     system_param_map.add()
-        ( BoolSwitch( &help ), "help" , "", "print help message.")
-        ( &coach_config_file, "coach-config", "", "specifies coach config file." );
+        ( "help" , "", BoolSwitch( &help ), "print help message.")
+        ( "coach-config", "", &coach_config_file, "specifies coach config file." );
 
     ParamMap coach_param_map( "Coach options" );
     M_config.createParamMap( coach_param_map );
 
-
-    CmdLineParser cmd_parser( argc, argv );
-
     // analyze command line for system options
     cmd_parser.parse( system_param_map );
     if ( help )
@@ -241,14 +235,12 @@ CoachAgent::doInit( const int argc,
     // analyze command line for coach options
     cmd_parser.parse( coach_param_map );
 
-    if ( ! cmd_parser.invalidOptions().empty() )
-    {
-        std::cerr << "coach: ***WARNING*** detected invalid options: ";
-        std::copy( cmd_parser.invalidOptions().begin(),
-                   cmd_parser.invalidOptions().end(),
-                   std::ostream_iterator< std::string >( std::cerr, " " ) );
-        std::cerr << std::endl;
-    }
+    //if ( ! cmd_parser.invalidOptions().empty() )
+    //{
+    //    std::cerr << "coach: ***WARNING*** detected invalid options: ";
+    //    cmd_parser.printError( std::cerr );
+    //    std::cerr << std::endl;
+    //}
     return true;
 }
 
@@ -345,7 +337,7 @@ CoachAgent::handleMessage()
     while ( recvMessage() > 0 )
     {
         ++counter;
-        parse( getRecvBuf() );
+        parse( recvBuf() );
     }
 
     if ( M_impl->current_time_.cycle() > start_time.cycle() + 1
