@@ -32,13 +32,13 @@
 #ifndef RCSC_COACH_COACH_AGENT_H
 #define RCSC_COACH_COACH_AGENT_H
 
-#include <string>
+#include <rcsc/coach/global_world_model.h>
+#include <rcsc/coach/coach_config.h>
+#include <rcsc/client/basic_client.h>
 
 #include <boost/scoped_ptr.hpp>
 
-#include <rcsc/client/basic_client.h>
-#include <rcsc/coach/coach_config.h>
-#include <rcsc/coach/global_world_model.h>
+#include <string>
 
 namespace rcsc {
 
@@ -108,15 +108,14 @@ public:
 protected:
     /*!
       \brief analyze command line options
-      \param argc the number of command line options
-      \param argv command line options strings
+      \param cmd_parser command lien parser object
+      \return only if "help" option is given, false is returned.
 
       This method is called from BasicClient::init( argc, argv )
       BasicClient::init(argc,argv) should be called in main().
      */
     virtual
-    bool doInit( const int argc,
-                 const char * const * argv );
+    bool doInit( CmdLineParser & cmd_parser );
 
     /*!
       \brief create connection to the server
