@@ -30,13 +30,13 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
-#include <rcsc/param/param_map.h>
-
 #include "coach_config.h"
 
+#include <rcsc/param/param_map.h>
+
 namespace rcsc {
 
 /*-------------------------------------------------------------------*/
@@ -94,24 +94,24 @@ void
 CoachConfig::createParamMap( ParamMap & param_map )
 {
     param_map.add()
-        ( &M_team_name, "team_name", "t" )
-        ( &M_version, "version", "v" )
+        ( "team_name", "t", &M_team_name )
+        ( "version", "v", &M_version )
 
-        ( &M_coach_name, "coach_name" )
-        ( &M_use_coach_name, "use_coach_name" )
+        ( "coach_name", "", &M_coach_name )
+        ( "use_coach_name", "", &M_use_coach_name )
 
-        ( &M_interval_msec, "interval_msec" )
-        ( &M_server_wait_seconds, "server_wait_seconds" )
+        ( "interval_msec", "", &M_interval_msec )
+        ( "server_wait_seconds", "", &M_server_wait_seconds )
 
-        ( &M_rcssserver_host, "host", "h" )
-        ( &M_rcssserver_port, "port" )
+        ( "host", "h",  &M_rcssserver_host )
+        ( "port", "", &M_rcssserver_port )
 
-        ( &M_use_eye, "use_eye" )
+        ( "use_eye", "", &M_use_eye )
 
-        ( &M_use_advise, "use_advise" )
-        ( &M_use_freeform, "use_freeform" )
+        ( "use_advise", "", &M_use_advise )
+        ( "use_freeform", "", &M_use_freeform )
 
-        ( &M_use_hetero, "use_hetero" )
+        ( "use_hetero", "", &M_use_hetero )
         ;
 }
 
