@@ -30,18 +30,17 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
+#include "circle_2d.h"
+#include "triangle_2d.h"
+#include "ray_2d.h"
+#include "line_2d.h"
+
 #include <iostream>
 #include <cmath>
 
-#include "line_2d.h"
-#include "ray_2d.h"
-#include "triangle_2d.h"
-
-#include "circle_2d.h"
-
 // available only this file
 namespace {
 
@@ -115,9 +114,9 @@ Circle2D::intersection( const Line2D & line,
                         Vector2D * sol1,
                         Vector2D * sol2 ) const
 {
-    if ( std::fabs( line.getA() ) < EPSILON )
+    if ( std::fabs( line.a() ) < EPSILON )
     {
-        if ( std::fabs( line.getB() ) < EPSILON )
+        if ( std::fabs( line.b() ) < EPSILON )
         {
             std::cerr << "Circle2D::intersection() illegal line."
                       << std::endl;
@@ -132,14 +131,14 @@ Circle2D::intersection( const Line2D & line,
             = QUADRATIC_FOMULA( 1.0,
                                 -2.0 * center().x,
                                 ( SQUARE( center().x )
-                                  + SQUARE( line.getC() / line.getB() + center().y )
+                                  + SQUARE( line.c() / line.b() + center().y )
                                   - SQUARE( radius() ) ),
                                 x1,
                                 x2 );
 
         if ( n_sol > 0 )
         {
-            double y1 = -line.getC() / line.getB();
+            double y1 = -line.c() / line.b();
             if ( sol1 )
             {
                 sol1->assign( x1, y1 );
@@ -158,8 +157,8 @@ Circle2D::intersection( const Line2D & line,
         //   Ax + By + C = 0
         //   (x - cx)^2 + (y - cy)^2 = r^2
         // make y's quadratic formula using these fomula.
-        double m = line.getB() / line.getA();
-        double d = line.getC() / line.getA();
+        double m = line.b() / line.a();
+        double d = line.c() / line.a();
 
         double a = 1.0 + m * m;
         double b = 2.0 * ( -center().y + ( d + center().x ) * m );
