@@ -30,13 +30,13 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
-#include <rcsc/geom/triangle_2d.h>
-
 #include "delaunay_triangulation.h"
 
+#include <rcsc/geom/triangle_2d.h>
+
 namespace rcsc {
 
 const double DelaunayTriangulation::EPSILON = 1.0e-5;
@@ -660,7 +660,7 @@ DelaunayTriangulation::updateOnlineVertex( const Vertex * new_vertex,
 
         if ( ! adjacent_vertex )
         {
-            std::cerr << __FILE__ << ':' << __LINE__ 
+            std::cerr << __FILE__ << ':' << __LINE__
                       << " updateOnliePoint()."
                       << " failed to find vertex of adjacent."
                       << std::endl;
