@@ -30,15 +30,15 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
+#include "gzfilterstream.h"
+
 #ifdef HAVE_LIBZ
 #include <zlib.h>
 #endif
 
-#include "gzfilterstream.h"
-
 namespace rcsc {
 
 /*!
