@@ -32,13 +32,10 @@
 #ifndef RCSC_GZ_GZFSTREAM_H
 #define RCSC_GZ_GZFSTREAM_H
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <boost/scoped_ptr.hpp>
 
 #include <iostream>
 #include <string>
-#include <boost/scoped_ptr.hpp>
 
 namespace rcsc {
 
@@ -137,7 +134,7 @@ public:
 
     /*!
       \brief open the file.
-      \param path file path to open
+      \param path file path
       \param mode specifies mode of I/O. Only std::ios_base::in or
       std::ios_base::out can be used.
       \param level compression level(0-9, -1 means default level)
