@@ -30,17 +30,18 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
-#include <cstdio>
-#include <sstream>
-#include <string>
+#include "player_type.h"
+#include "server_param.h"
 
 #include <rcsc/rcg/util.h>
 
-#include "server_param.h"
-#include "player_type.h"
+#include <sstream>
+#include <string>
+#include <cstdio>
+
 
 namespace rcsc {
 
@@ -484,8 +485,8 @@ PlayerType::normalizeAccel( const Vector2D & velocity,
     // if ( *accel_mag > sparam.playerAccelMax() )
     //     *accel_mag = sparam.playerAccelMax();
 
-    Vector2D dash_move( Vector2D::POLE,
-                        *accel_mag, accel_angle ); // set dash accel
+    Vector2D dash_move
+        = Vector2D::polar2vector( *accel_mag, accel_angle ); // set dash accel
     dash_move += velocity; // add current vel -> next move == player vel
     if ( dash_move.r2() > playerSpeedMax2() + 0.0001 )
     {
