@@ -32,14 +32,14 @@
 #ifndef RCSC_PARAM_PLAYER_TYPE_H
 #define RCSC_PARAM_PLAYER_TYPE_H
 
-#include <iostream>
-#include <map>
-#include <vector>
-
-#include <rcsc/types.h>
 #include <rcsc/geom/vector_2d.h>
 #include <rcsc/rcg/types.h>
 #include <rcsc/soccer_math.h>
+#include <rcsc/types.h>
+
+#include <map>
+#include <vector>
+#include <iostream>
 
 namespace rcsc {
 
@@ -255,7 +255,7 @@ public:
       \return const reference to the distance table container
      */
     const
-    std::vector< double > & getDashDistanceTable() const
+    std::vector< double > & dashDistanceTable() const
       {
           return M_dash_distance_table;
       }
@@ -293,7 +293,7 @@ public:
       }
     ////////////////////////////////////////////////
     /*!
-      \brief estimate to reach the specific distance
+      \brief estimate cycles to reach the specific distance with start speed 0.
       \param dash_dist distance to reach
       \return estimated cycles to reach
     */
@@ -303,6 +303,7 @@ public:
       \brief check if this type player can over player_speed_max
       \param dash_power used dash_power
       \param effort current effort value
+      \return true if player has the potential to go over the max speed
      */
     bool canOverSpeedMax( const double & dash_power,
                           const double & effort ) const
@@ -334,6 +335,7 @@ public:
       \brief estimate dash power to keep the specified speed
       \param speed the desired speed
       \param effort current effort value
+      \return estimated dash power, but not normalized
      */
     double getDashPowerToKeepSpeed( const double & speed,
                                     const double & effort ) const
@@ -343,8 +345,9 @@ public:
       }
 
     /*!
-      \brief estimate one cycle stamina comsumption
+      \brief estimate one cycle stamina comsumption to keep mas speed
       \param sparam server parameter
+      \return get the comsumed stamina value
      */
     double getOneStepStaminaComsumption( const ServerParam & sparam ) const
       {
@@ -366,6 +369,7 @@ public:
     /*!
       \brief calculate dash rate
       \param effort current effort value
+      \return dash power rate multiplied by effort
      */
     double dashRate( const double & effort ) const
       {
@@ -376,6 +380,7 @@ public:
       \brief calculate effective turn angle
       \param command_moment turn command argument
       \param speed current speed
+      \return estimated result turn angle
      */
     double effectiveTurn( const double & command_moment,
                           const double & speed ) const
@@ -387,6 +392,7 @@ public:
       \brief calculate final reachable speed
       \param dash_power used dash power
       \param effort current effort
+      \return maximal speed value with the specified params
      */
     double finalSpeed( const double & dash_power,
                        const double & effort ) const
@@ -400,6 +406,7 @@ public:
       \brief calculate inertia movement vector
       \param initial_vel initial velocity vector
       \param n_step cycles to be estimated
+      \return total travel vector
      */
     Vector2D inertiaTravel( const Vector2D & initial_vel,
                             const int n_step ) const
@@ -412,6 +419,7 @@ public:
       \param initial_pos initial point
       \param initial_vel initial velocity vector
       \param n_step cycles to be estimated
+      \rturn the reached point
      */
     Vector2D inertiaPoint( const Vector2D& initial_pos,
                            const Vector2D& initial_vel,
@@ -426,6 +434,7 @@ public:
     /*!
       \brief calculate total ineartia movement vector
       \param initial_vel initial velocity vector
+      \return total travel vector when plyer stops
      */
     Vector2D inertiaFinalTravel( const Vector2D & initial_vel ) const
       {
@@ -436,6 +445,7 @@ public:
       \brief calculate final reach point
       \param initial_pos initial position
       \param initial_vel initial velocity vector
+      \return the reached point when player stops
      */
     Vector2D inertiaFinalPoint( const Vector2D & initial_pos,
                                 const Vector2D & initial_vel ) const
@@ -593,7 +603,7 @@ public:
       \return const reference to the player type map object
      */
     const
-    PlayerTypeMap & getPlayerTypeMap() const
+    PlayerTypeMap & playerTypeMap() const
       {
           return M_player_type_map;
       }
@@ -603,7 +613,7 @@ public:
       \return const reference to the dummy player type paramaeter
      */
     const
-    PlayerType & getDummyType() const
+    PlayerType & dummyType() const
       {
           return M_dummy_type;
       }
