@@ -30,15 +30,15 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
-#include <iostream>
-#include <algorithm>
+#include "audio_codec.h"
 
 #include <rcsc/math_util.h>
 
-#include "audio_codec.h"
+#include <iostream>
+#include <algorithm>
 
 /*
   namespace {
@@ -463,6 +463,67 @@ AudioCodec::decodeCoordL2( const char ch1,
          );
 }
 
+
+/*-------------------------------------------------------------------*/
+/*!
+
+ */
+std::string
+AudioCodec::encodePosToStr7( const Vector2D & pos ) const
+{
+    double tmp = min_max( -52.5, pos.x, 52.5 );
+    tmp += 52.5;
+    tmp *= 10.0;
+    int ix = static_cast< int >( rint( tmp ) );
+
+    tmp = min_max( -34.0, pos.y, 34.0 );
+    tmp += 34.0;
+    tmp *= 10.0;
+    int iy = static_cast< int >( rint( tmp ) );
+
+    char xymsg[10];
+    std::snprintf( xymsg, 10, "%04d%03d", ix, iy );
+    if ( std::strlen( xymsg ) != 7 )
+    {
+        std::cerr << "AudioSensor::encodePosToStr7. "
+                  << "XY error(2) "
+                  << "( " << pos.x << pos.y << ")"
+                  << " -> " << xymsg << std::endl;
+        return std::string( "" );
+    }
+
+    return std::string( xymsg );
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+ */
+Vector2D
+AudioCodec::decodeStr7ToPos( const char * msg ) const
+{
+    if ( std::strlen( msg ) != 7 )
+    {
+        std::cerr << "AudioSensor::decode length error "
+                  << "[" << msg << "]" << std::endl;
+        return Vector2D::INVALIDATED;
+    }
+
+    int x = 0;
+    x += 1000 * (*msg - '0'); ++msg;
+    x += 100 * (*msg - '0'); ++msg;
+    x += 10 * (*msg - '0'); ++msg;
+    x += (*msg - '0'); ++msg;
+
+    int y = 0;
+    y += 100 * (*msg - '0'); ++msg;
+    y += 10 * (*msg - '0'); ++msg;
+    y += (*msg - '0'); ++msg;
+
+    return Vector2D( static_cast< double >( x ) * 0.1 - 52.5,
+                     static_cast< double >( y ) * 0.1 - 34.0 );
+}
+
 /*-------------------------------------------------------------------*/
 /*!
 
@@ -582,4 +643,56 @@ AudioCodec::decodeL6( const std::string & from,
     return true;
 }
 
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+char
+AudioCodec::unum2hex( const int unum )
+{
+    switch ( unum ) {
+    case 1: return '1'; break;
+    case 2: return '2'; break;
+    case 3: return '3'; break;
+    case 4: return '4'; break;
+    case 5: return '5'; break;
+    case 6: return '6'; break;
+    case 7: return '7'; break;
+    case 8: return '8'; break;
+    case 9: return '9'; break;
+    case 10: return 'A'; break;
+    case 11: return 'B'; break;
+    default:
+        break;
+    }
+
+    return '\0';
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+int
+AudioCodec::hex2unum( const char hex )
+{
+    switch ( hex ) {
+    case '1': return 1; break;
+    case '2': return 2; break;
+    case '3': return 3; break;
+    case '4': return 4; break;
+    case '5': return 5; break;
+    case '6': return 6; break;
+    case '7': return 7; break;
+    case '8': return 8; break;
+    case '9': return 9; break;
+    case 'A': return 10; break;
+    case 'B': return 11; break;
+    default:
+        break;
+    }
+
+    return 0;
+}
+
 }
