@@ -30,19 +30,19 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
+#include "audio_sensor.h"
+#include "logger.h"
+
+#include <rcsc/math_util.h>
+
 #include <cstdio>
 #include <cstdlib>
 #include <cstring>
 #include <cmath>
 
-#include <rcsc/math_util.h>
-
-#include "logger.h"
-#include "audio_sensor.h"
-
 namespace rcsc {
 
 /*-------------------------------------------------------------------*/
@@ -59,6 +59,12 @@ AudioSensor::AudioSensor()
     , M_goalie_pos( 50.0, 0.0 )
     , M_offside_line_x( 100000.0 )
     , M_defense_line_x( -100000.0 )
+    , M_intercept_time( 0, 0 )
+    , M_intercept_number( 0 )
+    , M_intercept_cycle( 1000 )
+    , M_hey_pass_time( 0, 0 )
+    , M_hey_pass_number( 0 )
+    , M_hey_pass_pos( 0.0, 0.0 )
 {
 
 }
@@ -89,13 +95,14 @@ AudioSensor::parsePlayer( const char * msg,
 
     M_time = current;
 
-    long cyc;
+    long cycle;
     double dir;
-    int num;
-    char tmp_msg[16];
+    int unum;
+    int n_read = 0;
 
-    if ( std::sscanf( msg, "(hear %ld %lf our %d %s",
-                      &cyc, &dir, &num, tmp_msg ) != 4 )
+    // v8+ complete message
+    if ( std::sscanf( msg, " (hear %ld %lf our %d %n ",
+                      &cycle, &dir, &unum, &n_read ) != 3 )
     {
         std::cerr << "***ERROR*** AudioSensor::parse."
                   << " got partial or opponent audio?? ["
@@ -104,32 +111,38 @@ AudioSensor::parsePlayer( const char * msg,
         return;
     }
 
+    msg += n_read;
 
-    const char * msg_ptr = msg;
-    while ( *msg_ptr != '\0' && *msg_ptr != '\"' ) ++msg_ptr; // " skip
 
-    if ( std::strlen( msg_ptr ) <= 3 ) // only ["")]
+    while ( *msg != '\0' && *msg == ' ' ) ++msg;
+    if ( *msg == '\"' ) ++msg;
+
+    std::size_t len = 0;
+    while ( *(msg + len) != '\0'
+            && *(msg + len) != '\"' )
+    {
+        ++len;
+    }
+
+    if ( len == 0 )
     {
         std::cerr << "***ERROR*** AudioSensor::parsePlayer."
                   << " Empty message "
-                  << "[" << msg << "]"
                   << std::endl;
         dlog.addText( Logger::SENSOR,
-                      "AudioSensor: Too short message [%s]",
-                      msg );
+                      "AudioSensor: Empty message" );
         return;
     }
 
+    M_player_message.message_.assign( msg, len );
 
     M_player_message.time_ = current;
     M_player_message.side_ = NEUTRAL;
-    M_player_message.unum_ = num;
-    M_player_message.type_ = PlayerMessage::NULL_INFO;
+    M_player_message.unum_ = unum;
+    M_player_message.type_ = PlayerMessage::ILLEGAL;
     M_player_message.dir_ = dir;
 
-    M_player_message.message_.erase();
-
-    parseTeammateAudioV8( msg_ptr );
+    parseTeammateAudioV8();
 }
 
 /*-------------------------------------------------------------------*/
@@ -302,42 +315,19 @@ AudioSensor::parseTrainer( const char * msg,
 
  */
 bool
-AudioSensor::parseTeammateAudioV8( const char * msg )
+AudioSensor::parseTeammateAudioV8()
 {
-    // can process only v8+ audio message
-
-    // go to first doubel quatation position
-    while ( *msg != '\0' && *msg != '\"' ) ++msg; // "
-
-    // check if double quatation is exist
-    if ( *msg != '\"' ) // "
+    if ( M_player_message.message_.empty() )
     {
-        std::cerr << "***ERROR*** AudioSensor::parseTeammateAudioV8"
-                  << " message is not quated [" << msg << "]"
-                  << std::endl;
         return false;
     }
 
-    // skip first double quatation
-    ++msg;
-
-    // copy raw audio message
-    {
-        const char * tmp = msg;
-        while ( *tmp != '\0' && *tmp != '\"' ) // "
-        {
-            M_player_message.message_ += *tmp;
-            ++tmp;
-        }
-    }
-
-    /////////////////////////////////////
-    // check message type
+    const char * msg = M_player_message.message_.c_str();
 
     // ball info
     if ( ! std::strncmp( msg, "b ", 2 ) )
     {
-        if ( *(msg + 8) != '\"' )
+        if ( M_player_message.message_.length() != 8 )
         {
             std::cerr << "***ERROR*** AudioSensor::parseTeammateAudioV8"
                       << " Illega ball info [" << msg << "]"
@@ -347,21 +337,23 @@ AudioSensor::parseTeammateAudioV8( const char * msg )
                           msg );
             return false;
         }
-        std::string ball_str( msg + 2, 6 );
-        if ( M_codec.decodeL6( ball_str, &M_ball_pos, &M_ball_vel ) )
-        {
-            M_player_message.type_ = PlayerMessage::BALL_INFO;
-            return true;
-        }
-        std::cerr << "***ERROR*** AudioSensor::parseTeammateAudioV8"
-                  << " Failed to decode ball [" << msg
-                  << "]  str=["  << ball_str << "]"
-                  << std::endl;
-        dlog.addText( Logger::SENSOR,
-                      "AudioSensor: Failed to decode Ball Info [%s]",
-                      msg );
 
-        return false;
+        std::string ball_str = M_player_message.message_.substr( 2, 6 );
+        if ( ! M_codec.decodeL6( ball_str, &M_ball_pos, &M_ball_vel ) )
+        {
+            std::cerr << "***ERROR*** AudioSensor::parseTeammateAudioV8"
+                      << " Failed to decode ball [" << msg
+                      << "]  str=["  << ball_str << "]"
+                      << std::endl;
+            dlog.addText( Logger::SENSOR,
+                          "AudioSensor: Failed to decode Ball Info [%s]",
+                          msg );
+
+            return false;
+        }
+
+        M_player_message.type_ = PlayerMessage::BALL_INFO;
+        return true;
     }
     ////////////////////////////////////////////////////////
     // pass info
@@ -426,7 +418,7 @@ AudioSensor::parseTeammateAudioV8( const char * msg )
             return true;
         }
         std::cerr  << "***ERROR*** AudioSensor::parseTeammateAudioV8"
-                   << " Failed to decode M_messagetypine [" << msg << "]"
+                   << " Failed to decode defense line [" << msg << "]"
                    << std::endl;
         dlog.addText( Logger::SENSOR,
                       "AudioSensor: Failed to decode Defense Line Info [%s]",
@@ -451,22 +443,32 @@ AudioSensor::parseTeammateAudioV8( const char * msg )
     }
 
     ////////////////////////////////////////////////////////
-    // read default ball info
-
-    // decode ball info
-    if ( M_codec.decodeL5( M_player_message.message_, &M_ball_pos, &M_ball_vel ) )
+    // intercept info
+    if ( ! std::strncmp( msg, "i ", 2 ) )
     {
-        M_player_message.type_ = PlayerMessage::BALL_INFO;
-
+        if ( parseInterceptInfo( msg ) )
+        {
+            M_player_message.type_ = PlayerMessage::INTERCEPT;
+            return true;
+        }
+        std::cerr  << "***ERROR*** AudioSensor::parseTeammateAudioV8"
+                   << " Failed to decode intercept info [" << msg << "]"
+                   << std::endl;
         dlog.addText( Logger::SENSOR,
-                      "AudioSensor: success! sender=%d  ball_pos(%.1f %.1f)"
-                      " ball_vel(%.1f %.1f)",
-                      M_player_message.unum_,
-                      M_ball_pos.x, M_ball_pos.y,
-                      M_ball_vel.x, M_ball_vel.y );
+                      "AudioSensor: Failed to decode intercept info [%s]",
+                      msg );
+        return false;
+    }
+
+    ////////////////////////////////////////////////////////
+    // hey pass info
+    if ( ! std::strncmp( msg, "h ", 2 ) )
+    {
+        M_player_message.type_ = PlayerMessage::HEY_PASS;
         return true;
     }
 
+
     //std::cerr << "***ERROR*** AudioSensor::parseTeammateAudioV8"
     //          << " Failed to decode ["
     //          << raw_message << "]" << std::endl;
@@ -615,72 +617,6 @@ AudioSensor::encodePass( const int receiver,
     say_buf += xymsg;
 }
 
-/*-------------------------------------------------------------------*/
-/*!
-
- */
-bool
-AudioSensor::decodeStr7ToPos( const char* msg,
-                              Vector2D* pos )
-{
-    if ( std::strlen( msg ) <= 7 )
-    {
-        std::cerr << "AudioSensor::decode length error "
-                  << "[" << msg << "]" << std::endl;
-        return false;
-    }
-
-    int x = 0;
-    x += 1000 * (*msg - '0'); ++msg;
-    x += 100 * (*msg - '0'); ++msg;
-    x += 10 * (*msg - '0'); ++msg;
-    x += (*msg - '0'); ++msg;
-
-    int y = 0;
-    y += 100 * (*msg - '0'); ++msg;
-    y += 10 * (*msg - '0'); ++msg;
-    y += (*msg - '0'); ++msg;
-
-    pos->x = static_cast< double >( x ) * 0.1 - 52.5;
-    pos->y = static_cast< double >( y ) * 0.1 - 34.0;
-
-    return true;
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-
- */
-bool
-AudioSensor::encodePosToStr7( const Vector2D & pos,
-                              std::string & msg ) const
-{
-    double tmp = min_max( -52.5, pos.x, 52.5 );
-    tmp += 52.5;
-    tmp *= 10.0;
-    int ix = static_cast< int >( rint( tmp ) );
-
-    tmp = min_max( -34.0, pos.y, 34.0 );
-    tmp += 34.0;
-    tmp *= 10.0;
-    int iy = static_cast< int >( rint( tmp ) );
-
-    char xymsg[10];
-    std::snprintf( xymsg, 10, "%04d%03d", ix, iy );
-    if ( std::strlen( xymsg ) != 7 )
-    {
-        std::cerr << "AudioSensor::encodePosToStr7. "
-                  << "XY error(2) "
-                  << "( " << pos.x << pos.y << ")"
-                  << " -> " << xymsg << std::endl;
-        return false;
-    }
-
-    msg += xymsg;
-
-    return true;
-}
-
 /*-------------------------------------------------------------------*/
 /*!
 
@@ -692,19 +628,9 @@ AudioSensor::encodeGoalie( const int goalie_number,
 {
     say_buf = "g ";
 
-    switch ( goalie_number ) {
-    case 1: say_buf += "1"; break;
-    case 2: say_buf += "2"; break;
-    case 3: say_buf += "3"; break;
-    case 4: say_buf += "4"; break;
-    case 5: say_buf += "5"; break;
-    case 6: say_buf += "6"; break;
-    case 7: say_buf += "7"; break;
-    case 8: say_buf += "8"; break;
-    case 9: say_buf += "9"; break;
-    case 10: say_buf += "A "; break;
-    case 11: say_buf += "B"; break;
-    default:
+    char hex = AudioCodec::unum2hex( goalie_number );
+    if ( hex == '\0' )
+    {
         std::cerr << "AudioSensor::encodeGoalieInfo. "
                   << "Unexpected goalie number "
                   << goalie_number << std::endl;
@@ -712,7 +638,10 @@ AudioSensor::encodeGoalie( const int goalie_number,
         return;
     }
 
-    if ( ! encodePosToStr7( goalie_pos, say_buf ) )
+    say_buf += hex;
+
+    std::string pos_str = codec().encodePosToStr7( goalie_pos );
+    if ( pos_str.length() != 7 )
     {
         std::cerr << "AudioSensor::encodeGoalieInfo. "
                   << "Failed to encode goalie info "
@@ -720,6 +649,56 @@ AudioSensor::encodeGoalie( const int goalie_number,
                   << std::endl;
         say_buf.erase();
     }
+
+    say_buf += pos_str;
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+ */
+bool
+AudioSensor::parseGoalieInfo( const char * msg )
+{
+    if ( std::strlen( msg ) != 10
+         || msg[0] != 'g'
+         || msg[1] != ' ' )
+    {
+        std::cerr << "AudioSensor::parseGoalieInfo. "
+                  << "Unexpected goalie message ["
+                  << msg << "] len = " << std::strlen( msg )
+                  << std::endl;
+        return false;
+    }
+    msg += 2;
+
+    int unum = AudioCodec::hex2unum( *msg );
+    if ( unum == 0 )
+    {
+        std::cerr << "AudioSensor::parseGoalieInfo. "
+                  << "Unexpected goalie number " << msg
+                  << std::endl;
+        return false;
+    }
+
+    ++msg;
+
+    M_goalie_pos = codec().decodeStr7ToPos( msg );
+
+    if ( ! M_goalie_pos )
+    {
+        std::cerr << "AudioSensor::parseGoalieInfo. "
+                  << " Failed to decode goalie potiiton"
+                  << std::endl;
+        dlog.addText( Logger::SENSOR,
+                      "AudioSensor: Failed to decode goalie potiiton" );
+        return false;
+    }
+
+    dlog.addText( Logger::SENSOR,
+                  "AudioSensor: success!  goalie pos = (%.2f %.2f)",
+                  M_goalie_pos.x, M_goalie_pos.y );
+    return true;
 }
 
 /*-------------------------------------------------------------------*/
@@ -735,75 +714,6 @@ AudioSensor::encodeOffsideLineX( const double & offside_line_x,
     say_buf = buf;
 }
 
-/*-------------------------------------------------------------------*/
-/*!
-
- */
-void
-AudioSensor::encodeDefenseLineX( const double & defense_line_x,
-                                 std::string & say_buf ) const
-{
-    char buf[10];
-    std::snprintf( buf, 10, "d %.1f", defense_line_x );
-    say_buf = buf;
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-
- */
-bool
-AudioSensor::parseGoalieInfo( const char* msg )
-{
-    if ( std::strlen( msg ) <= 10
-         || msg[0] != 'g'
-         || msg[1] != ' ' )
-    {
-        std::cerr << "AudioSensor::parseGoalieInfo. "
-                  << "Unexpected goalie message ["
-                  << msg << "]"
-                  << std::endl;
-        return false;
-    }
-    msg += 2;
-
-    switch ( *msg ) {
-    case '1': M_goalie_number = 1; break;
-    case '2': M_goalie_number = 2; break;
-    case '3': M_goalie_number = 3; break;
-    case '4': M_goalie_number = 4; break;
-    case '5': M_goalie_number = 5; break;
-    case '6': M_goalie_number = 6; break;
-    case '7': M_goalie_number = 7; break;
-    case '8': M_goalie_number = 8; break;
-    case '9': M_goalie_number = 9; break;
-    case 'A': M_goalie_number = 10; break;
-    case 'B': M_goalie_number = 11; break;
-    default:
-        std::cerr << "AudioSensor::parseGoalieInfo. "
-                  << "Unexpected goalie number " << msg
-                  << std::endl;
-        return false;
-    }
-
-    ++msg;
-
-    if ( decodeStr7ToPos( msg, &M_goalie_pos ) )
-    {
-        dlog.addText( Logger::SENSOR,
-                      "AudioSensor: success!  goalie pos = (f %f)",
-                      M_goalie_pos.x, M_goalie_pos.y );
-        return true;
-    }
-
-    std::cerr << "AudioSensor::parseGoalieInfo. "
-              << " Failed to decode goalie potiiton"
-              << std::endl;
-    dlog.addText( Logger::SENSOR,
-                  "AudioSensor: Failed to decode goalie potiiton" );
-    return false;
-}
-
 /*-------------------------------------------------------------------*/
 /*!
   "o <x>"
@@ -839,6 +749,18 @@ AudioSensor::parseOffsideLineInfo( const char * msg )
     return true;
 }
 
+/*-------------------------------------------------------------------*/
+/*!
+
+ */
+void
+AudioSensor::encodeDefenseLineX( const double & defense_line_x,
+                                 std::string & say_buf ) const
+{
+    char buf[10];
+    std::snprintf( buf, 10, "d %.1f", defense_line_x );
+    say_buf = buf;
+}
 
 /*-------------------------------------------------------------------*/
 /*!
@@ -875,4 +797,136 @@ AudioSensor::parseDefenseLineInfo( const char * msg )
     return true;
 }
 
+/*-------------------------------------------------------------------*/
+/*!
+
+ */
+void
+AudioSensor::encodeInterceptInfo( const int unum,
+                                  const int cycle,
+                                  std::string & say_buf ) const
+{
+    char buf[10];
+    std::snprintf( buf, 10, "i %d %d", unum, cycle );
+    say_buf = buf;
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+ */
+bool
+AudioSensor::parseInterceptInfo( const char * msg )
+{
+    if ( msg[0] != 'i'
+         || msg[1] != ' ' )
+    {
+        std::cerr << "AudioSensor::parseInterceptInfo. "
+                  << "Unexpected message Id ["
+                  << msg << "]"
+                  << std::endl;
+        return false;
+    }
+
+    int unum = 0;
+    int cycle = 0;
+
+    if ( std::sscanf( msg, "i %d %d", &unum , &cycle ) != 2 )
+    {
+        std::cerr << "AudioSensor::parseInterceptInfo. "
+                  << "Unexpected value message(2) ["
+                  << msg << "]"
+                  << std::endl;
+        return false;
+    }
+
+    M_intercept_time = M_time;
+    M_intercept_number = unum;
+    M_intercept_cycle = cycle;
+
+    return true;
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+ */
+void
+AudioSensor::encodeHeyPassInfo( const int unum,
+                                const Vector2D & pos,
+                                std::string & say_buf ) const
+{
+    char hex = AudioCodec::unum2hex( unum );
+    if ( hex == '\0' )
+    {
+        return;
+    }
+
+    say_buf = "i ";
+    say_buf += hex;
+
+    std::string pos_str = codec().encodePosToStr7( pos );
+    if ( pos_str.length() != 7 )
+    {
+        std::cerr << "AudioSensor::encodeHeyPassInfo. "
+                  << "Failed to encode hey passe info. unum="
+                  << unum
+                  << " ( " << pos.x << pos.y << ")"
+                  << std::endl;
+        say_buf.erase();
+    }
+
+    say_buf += pos_str;
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+ */
+bool
+AudioSensor::parseHeyPassInfo( const char * msg )
+{
+    if ( std::strlen( msg ) != 10
+         || msg[0] != 'h'
+         || msg[1] != ' ' )
+    {
+        std::cerr << "AudioSensor::parseHeyPassInfo. "
+                  << "Unexpected hey pass message ["
+                  << msg << "] len = " << std::strlen( msg )
+                  << std::endl;
+        return false;
+    }
+    msg += 2;
+
+    M_hey_pass_number = AudioCodec::hex2unum( *msg );
+    if ( M_hey_pass_number == 0 )
+    {
+        std::cerr << "AudioSensor::parseGoalieInfo. "
+                  << "Unexpected goalie number " << msg
+                  << std::endl;
+        return false;
+    }
+
+    ++msg;
+
+    M_hey_pass_pos = codec().decodeStr7ToPos( msg );
+
+    if ( ! M_hey_pass_pos )
+    {
+        std::cerr << "AudioSensor::parseHeyPassInfo. "
+                  << " Failed to decode hey pass potiiton"
+                  << std::endl;
+        dlog.addText( Logger::SENSOR,
+                      "AudioSensor: Failed to decode hey pass potiiton" );
+        return false;
+    }
+
+    dlog.addText( Logger::SENSOR,
+                  "AudioSensor: success!  hey pass pos = (%.2f %.2f)",
+                  M_hey_pass_pos.x, M_hey_pass_pos.y );
+
+    M_hey_pass_time = M_time;
+    return true;
+}
+
 }
