@@ -30,23 +30,22 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
+#include "debug_client.h"
+#include "world_model.h"
+#include "player_object.h"
+
+#include <rcsc/net/udp_socket.h>
+
+#include <algorithm>
+#include <sstream>
+#include <iostream>
 #include <cstdarg>
 #include <cstdio>
 #include <cstring>
 #include <cmath>
-#include <iostream>
-#include <sstream>
-#include <algorithm>
-
-#include <rcsc/net/udp_socket.h>
-
-#include "player_object.h"
-#include "world_model.h"
-
-#include "debug_client.h"
 
 namespace rcsc {
 
@@ -208,7 +207,7 @@ DebugClient::DebugClient()
     , M_connected( false )
     , M_main_buffer( "" )
     , M_target_unum( 0 )
-    , M_target_point( Vector2D::INVALID )
+    , M_target_point( Vector2D::INVALIDATED )
     , M_message( "" )
     , M_freeforms( "" )
 {
@@ -515,7 +514,7 @@ DebugClient::clear()
 {
     M_main_buffer.erase();
     M_target_unum = 0;
-    M_target_point.assign( Vector2D::INVALID );
+    M_target_point.invalidate();
     M_message.erase();
     M_lines.clear();
     M_triangles.clear();
