@@ -174,6 +174,10 @@ public:
                 const double & version,
                 const GameTime & current );
 
+    /*!
+      \brief reverse the coordinate system
+     */
+    void reverse();
 
     // accessor method
 
