@@ -30,18 +30,17 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
-#include <algorithm>
-
-#include <rcsc/random.h>
-#include <rcsc/geom/sector_2d.h>
-
-#include "logger.h"
-#include "object_table.h"
-
 #include "localization.h"
+#include "object_table.h"
+#include "logger.h"
+
+#include <rcsc/geom/sector_2d.h>
+#include <rcsc/random.h>
+
+#include <algorithm>
 
 using std::min;
 using std::max;
@@ -660,8 +659,7 @@ LocalizeImpl::generateParticles( const VisualSensor::MarkerT & marker,
           add_dir < dir_range + 0.01;
           add_dir += dir_inc )
     {
-        Vector2D base_vec( Vector2D::POLE,
-                           min_dist, base_angle );
+        Vector2D base_vec = Vector2D::polar2vector( min_dist, base_angle );
         for ( double add_dist = 0.0;
               add_dist < dist_range + 0.08;
               add_dist += 0.045 )
@@ -806,10 +804,10 @@ LocalizeImpl::getFaceDirByMarkers( const VisualSensor::MarkerCont & markers )
         return angle;
     }
 
-    Vector2D mrpos1( Vector2D::POLE,
-                     marker_dist1, markers.front().dir_ );
-    Vector2D mrpos2( Vector2D::POLE,
-                     marker_dist2, markers.back().dir_ );
+    Vector2D mrpos1
+        = Vector2D::polar2vector( marker_dist1, markers.front().dir_ );
+    Vector2D mrpos2
+        = Vector2D::polar2vector( marker_dist2, markers.back().dir_ );
     Vector2D gap1 = mrpos1 - mrpos2;
     Vector2D gap2 = it1->second - it2->second;
 
@@ -968,7 +966,7 @@ Localization::localizeSelf( const VisualSensor::LineCont & lines,
     ////////////////////////////////////////////////////////////////////
     // initialize
     // self_pos must be assigned ERROR_VALUE
-    self_pos->assign( Vector2D::INVALID );
+    self_pos->invalidate();
     self_pos_err->assign( 0.0, 0.0 );
     *self_face_err = 0.0;
 
@@ -1307,7 +1305,7 @@ Localization::localizePlayer( const VisualSensor::PlayerT & from,
     }
     else
     {
-        to->vel_.assign( Vector2D::INVALID );
+        to->vel_.invalidate();
     }
 
     ////////////////////////////////////////////////////////////////////
