@@ -30,16 +30,16 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
-#include <iostream>
-#include <algorithm>
-#include <cmath>
+#include "object_table.h"
 
 #include <rcsc/param/server_param.h>
 
-#include "object_table.h"
+#include <algorithm>
+#include <iostream>
+#include <cmath>
 
 namespace rcsc {
 
