@@ -1304,6 +1304,10 @@ PlayerAgent::analyzeFullstate( const char * msg )
     M_impl->fullstate_.parse( msg,
                               config().version(),
                               M_impl->current_time_ );
+    if ( world().isOurRight() )
+    {
+        M_impl->fullstate_.reverse();
+    }
 
     if ( config().useFullstate() )
     {
