@@ -30,17 +30,15 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
-#include <cassert>
+#include "player_config.h"
+#include "logger.h"
 
 #include <rcsc/param/param_map.h>
 
-#include "logger.h"
-#include "player_agent.h"
-
-#include "player_config.h"
+#include <cassert>
 
 namespace rcsc {
 
@@ -147,68 +145,67 @@ void
 PlayerConfig::createParamMap( ParamMap & param_map )
 {
     param_map.add()
-        ( &M_team_name,"team_name", "t", "specifies team name string." )
-        ( &M_version, "version", "v", "specifies the protocol version to communicate with the rcssserver." )
-        ( &M_reconnect_number, "reconnect", "r",
+        ( "team_name", "t", &M_team_name, "specifies team name string." )
+        ( "version", "v", &M_version, "specifies the protocol version to communicate with the rcssserver." )
+        ( "reconnect", "r", &M_reconnect_number,
           "recconect to the rcssserver. This option requres the player\'s uniform number for the reconnection." )
 
-        ( BoolSwitch( &M_goalie ), "goalie", "g" )
+        ( "goalie", "g", BoolSwitch( &M_goalie ) )
 
-        ( &M_interval_msec, "interval_msec" )
-        ( &M_server_wait_seconds, "server_wait_seconds" )
+        ( "interval_msec", "", &M_interval_msec )
+        ( "server_wait_seconds", "", &M_server_wait_seconds )
 
-        ( &M_wait_time_thr_synch_view, "wait_time_thr_synch_view" )
-        ( &M_wait_time_thr_nosynch_view, "wait_time_thr_nosynch_view" )
+        ( "wait_time_thr_synch_view", "", &M_wait_time_thr_synch_view )
+        ( "wait_time_thr_nosynch_view","", &M_wait_time_thr_nosynch_view )
 
-        ( &M_normal_view_time_thr, "normal_view_time_thr" )
+        ( "normal_view_time_thr", "", &M_normal_view_time_thr )
 
-        ( &M_rcssserver_host, "host", "h" )
-        ( &M_rcssserver_port, "port" )
+        ( "host", "h", &M_rcssserver_host )
+        ( "port", "", &M_rcssserver_port )
 
-        ( &M_clang_min, "clang_min" )
-        ( &M_clang_max, "clang_max" )
+        ( "clang_min", "", &M_clang_min )
+        ( "clang_max", "", &M_clang_max )
 
-        ( &M_use_communication, "use_communication" )
-        ( &M_hear_opponent_audio, "hear_opponent_audio" )
+        ( "use_communication", "", &M_use_communication )
+        ( "hear_opponent_audio", "", &M_hear_opponent_audio )
 
-        ( &M_use_fullstate, "use_fullstate" )
+        ( "use_fullstate", "", &M_use_fullstate )
 
-        ( &M_self_pos_count_thr, "self_pos_count_thr" )
-        ( &M_self_vel_count_thr, "self_vel_count_thr" )
-        ( &M_self_face_count_thr, "self_face_count_thr" )
-        ( &M_ball_pos_count_thr, "ball_pos_count_thr" )
-        ( &M_ball_rpos_count_thr, "ball_rpos_count_thr" )
-        ( &M_ball_vel_count_thr, "ball_vel_count_thr" )
-        ( &M_player_pos_count_thr, "player_pos_count_thr" )
-        ( &M_player_vel_count_thr, "player_vel_count_thr" )
-        ( &M_player_face_count_thr, "player_face_count_thr" )
+        ( "self_pos_count_thr", "", &M_self_pos_count_thr )
+        ( "self_vel_count_thr", "", &M_self_vel_count_thr )
+        ( "self_face_count_thr", "", &M_self_face_count_thr )
+        ( "ball_pos_count_thr", "", &M_ball_pos_count_thr )
+        ( "ball_rpos_count_thr", "", &M_ball_rpos_count_thr )
+        ( "ball_vel_count_thr", "", &M_ball_vel_count_thr )
+        ( "player_pos_count_thr", "", &M_player_pos_count_thr )
+        ( "player_vel_count_thr", "", &M_player_vel_count_thr )
+        ( "player_face_count_thr", "", &M_player_face_count_thr )
 
-        ( &M_config_dir, "config_dir" )
-        ( &M_player_number, "player_number", "n" )
+        ( "config_dir", "", &M_config_dir )
+        ( "player_number", "n",  &M_player_number )
 
-        //( &M_debug_connect, PARAM_SWITCH, "debug_connect" )
-        ( BoolSwitch( &M_debug_connect ), "debug_connect" )
-        ( &M_debug_server_host, "debug_server_host" )
-        ( &M_debug_server_port, "debug_server_port" )
+        ( "debug_connect", "", BoolSwitch( &M_debug_connect ) )
+        ( "debug_server_host", "", &M_debug_server_host )
+        ( "debug_server_port", "", &M_debug_server_port )
 
-        ( BoolSwitch( &M_debug_write ), "debug_write" )
+        ( "debug_write", "", BoolSwitch( &M_debug_write ) )
 
-        ( &M_log_dir, "log_dir" )
+        ( "log_dir", "", &M_log_dir )
 
-        ( BoolSwitch( &M_debug ), "debug" )
-        ( BoolSwitch( &M_debug_system ), "debug_system" )
-        ( BoolSwitch( &M_debug_sensor ), "debug_sensor" )
-        ( BoolSwitch( &M_debug_world ), "debug_world" )
-        ( BoolSwitch( &M_debug_action ), "debug_action" )
-        ( BoolSwitch( &M_debug_intercept ), "debug_intercept" )
-        ( BoolSwitch( &M_debug_kick ), "debug_kick" )
-        ( BoolSwitch( &M_debug_dribble ), "debug_dribble" )
-        ( BoolSwitch( &M_debug_pass ), "debug_pass" )
-        ( BoolSwitch( &M_debug_cross ), "debug_cross" )
-        ( BoolSwitch( &M_debug_shoot ), "debug_shoot" )
-        ( BoolSwitch( &M_debug_clear ), "debug_clear" )
-        ( BoolSwitch( &M_debug_team ), "debug_team" )
-        ( BoolSwitch( &M_debug_role ), "debug_role" );
+        ( "debug", "", BoolSwitch( &M_debug ) )
+        ( "debug_system", "", BoolSwitch( &M_debug_system ) )
+        ( "debug_sensor", "", BoolSwitch( &M_debug_sensor ) )
+        ( "debug_world", "", BoolSwitch( &M_debug_world ) )
+        ( "debug_action", "", BoolSwitch( &M_debug_action ) )
+        ( "debug_intercept", "", BoolSwitch( &M_debug_intercept ) )
+        ( "debug_kick", "", BoolSwitch( &M_debug_kick ) )
+        ( "debug_dribble", "", BoolSwitch( &M_debug_dribble ) )
+        ( "debug_pass", "", BoolSwitch( &M_debug_pass ) )
+        ( "debug_cross", "", BoolSwitch( &M_debug_cross ) )
+        ( "debug_shoot", "", BoolSwitch( &M_debug_shoot ) )
+        ( "debug_clear", "", BoolSwitch( &M_debug_clear ) )
+        ( "debug_team", "", BoolSwitch( &M_debug_team ) )
+        ( "debug_role", "", BoolSwitch( &M_debug_role ) );
 }
 
 }
