@@ -30,19 +30,18 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
-#include <rcsc/soccer_math.h>
-#include <rcsc/param/server_param.h>
-#include <rcsc/param/player_type.h>
-
-#include "logger.h"
+#include "player_intercept.h"
+#include "world_model.h"
 #include "ball_object.h"
 #include "player_object.h"
-#include "world_model.h"
+#include "logger.h"
 
-#include "player_intercept.h"
+#include <rcsc/param/server_param.h>
+#include <rcsc/param/player_type.h>
+#include <rcsc/soccer_math.h>
 
 namespace rcsc {
 
@@ -235,8 +234,8 @@ PlayerIntercept::canReachAfterDash( const int n_turn,
 
     double dash_accel_mag = ( ServerParam::i().maxPower()
                               * player_type.dashRate( player_type.effortMax() ) );
-    const Vector2D dash_accel( Vector2D::POLE,
-                               dash_accel_mag, dash_angle );
+    const Vector2D dash_accel
+        = Vector2D::polar2vector( dash_accel_mag, dash_angle );
 
     for ( int i = 0; i < n_dash; ++i )
     {
