@@ -30,21 +30,21 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
-#include <rcsc/math_util.h>
-#include <rcsc/soccer_math.h>
-#include <rcsc/param/server_param.h>
-#include <rcsc/param/player_type.h>
+#include "self_intercept.h"
 
-#include "logger.h"
+#include "world_model.h"
+#include "intercept_table.h"
 #include "self_object.h"
 #include "ball_object.h"
-#include "world_model.h"
+#include "logger.h"
 
-#include "intercept_table.h"
-#include "self_intercept.h"
+#include <rcsc/param/server_param.h>
+#include <rcsc/param/player_type.h>
+#include <rcsc/soccer_math.h>
+#include <rcsc/math_util.h>
 
 namespace rcsc {
 
