@@ -30,25 +30,25 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
+#include "self_object.h"
+
+#include "action_effector.h"
+#include "ball_object.h"
+#include "debug_client.h"
+#include "body_sensor.h"
+#include "fullstate_sensor.h"
+#include "logger.h"
+
+#include <rcsc/param/server_param.h>
+#include <rcsc/soccer_math.h>
+
 #include <algorithm>
 #include <iostream>
 #include <cmath>
 
-#include <rcsc/soccer_math.h>
-#include <rcsc/param/server_param.h>
-
-#include "logger.h"
-#include "body_sensor.h"
-#include "fullstate_sensor.h"
-#include "ball_object.h"
-#include "action_effector.h"
-#include "debug_client.h"
-
-#include "self_object.h"
-
 namespace rcsc {
 
 int SelfObject::S_pos_count_thr = 20;
@@ -64,10 +64,10 @@ SelfObject::SelfObject()
     , M_sense_body_time( -1, 0 )
     , M_unum( 0 )
     , M_goalie( false )
-    , M_pos( Vector2D::INVALID )
+    , M_pos( Vector2D::INVALIDATED )
     , M_pos_error( 0.0, 0.0 )
     , M_pos_count( 1000 )
-    , M_pos_prev( Vector2D::INVALID )
+    , M_pos_prev( Vector2D::INVALIDATED )
     , M_vel( 0.0, 0.0 )
     , M_vel_error( 0.0, 0.0 )
     , M_vel_count( 0 )
@@ -81,7 +81,7 @@ SelfObject::SelfObject()
     , M_last_catch_time( 0, 0 )
     , M_tackle_expires( 0 )
     , M_arm_movable( 0 )
-    , M_pointto_pos( Vector2D::INVALID )
+    , M_pointto_pos( Vector2D::INVALIDATED )
     , M_last_pointto_time( 0, 0 )
     , M_attentionto_side( NEUTRAL )
     , M_attentionto_unum( 0 )
@@ -200,7 +200,7 @@ SelfObject::update( const ActionEffector & act,
 
     /////////////////////////////////////////
     // base command
-    switch ( act.getLastCommandType() ) {
+    switch ( act.lastBodyCommandType() ) {
     case PlayerCommand::DASH:
         act.getDashInfo( &acc, &dash_pow );
         break;
@@ -216,7 +216,7 @@ SelfObject::update( const ActionEffector & act,
         //M_vel_error.assign( 0.0, 0.0 );
         break;
     case PlayerCommand::CATCH:
-        M_last_catch_time = act.getLastActionTime();
+        M_last_catch_time = act.lastActionTime();
         break;
     case PlayerCommand::KICK:
         break;
@@ -557,7 +557,7 @@ SelfObject::updateAfterSense( const BodySensor & sense,
         }
         else
         {
-            M_last_move.assign( Vector2D::INVALID );
+            M_last_move.invalidate();
         }
     }
 
