@@ -30,16 +30,16 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
-#include <cmath> // HUGE_VAL
-#include <algorithm>
-#include <iterator>
+#include "visual_sensor.h"
 
 #include "logger.h"
 
-#include "visual_sensor.h"
+#include <iterator>
+#include <algorithm>
+#include <cmath> // HUGE_VAL
 
 namespace rcsc {
 
