@@ -32,20 +32,19 @@
 #ifndef RCSC_PLAYER_WORLD_MODEL_H
 #define RCSC_PLAYER_WORLD_MODEL_H
 
-#include <vector>
-#include <list>
-#include <deque>
-#include <string>
-
-#include <rcsc/types.h>
-#include <rcsc/game_time.h>
-#include <rcsc/game_mode.h>
-#include <rcsc/geom/vector_2d.h>
-
 #include <rcsc/player/self_object.h>
 #include <rcsc/player/ball_object.h>
 #include <rcsc/player/player_object.h>
 
+#include <rcsc/geom/vector_2d.h>
+#include <rcsc/game_mode.h>
+#include <rcsc/game_time.h>
+#include <rcsc/types.h>
+
+#include <list>
+#include <vector>
+#include <string>
+
 namespace rcsc {
 
 class PlayerType;
@@ -186,14 +185,14 @@ public:
       \return const pointer to the intercept table instance
     */
     const
-    InterceptTable * getInterceptTable() const;
+    InterceptTable * interceptTable() const;
 
     /*!
       \brief get penalty kick state
       \return const pointer to the penalty kick state instance
     */
     const
-    PenaltyKickState * getPenaltyKickState() const;
+    PenaltyKickState * penaltyKickState() const;
 
     /*!
       \brief init team info
@@ -488,7 +487,6 @@ public:
       {
           return M_teamname;
       }
-    const std::string & getTeamName() const { return teamName(); }
 
     /*!
       \brief get our team side Id
@@ -498,7 +496,6 @@ public:
       {
           return M_our_side;
       }
-    SideID getOurSide() const { return ourSide(); }
 
     /*!
       \brief check if our team is left or not
@@ -527,8 +524,6 @@ public:
       {
           return M_time;
       }
-    const GameTime & getTime() const { return time(); }
-
 
     /*!
       \brief get last time updated by see
@@ -539,7 +534,6 @@ public:
       {
           return M_see_time;
       }
-    const GameTime & getSeeUpdateTime() const { return seeTime(); }
 
     /*!
       \brief get last time updated by fullstate
@@ -560,7 +554,7 @@ public:
       \return counted long integer
     */
     const
-    long & getSetPlayCount() const
+    long & setplayCount() const
       {
           return M_setplay_count;
       }
@@ -574,8 +568,6 @@ public:
       {
           return M_game_mode;
       }
-    const GameMode & getGameMode() const { return gameMode(); }
-
 
     /*!
       \brief get self info
@@ -658,7 +650,6 @@ public:
       {
           return M_teammates_from_self;
       }
-    const PlayerPtrCont & getTeammatesFromSelf() const { return teammatesFromSelf(); }
 
     /*!
       \brief get opponents sorted by distance from self
@@ -669,7 +660,6 @@ public:
       {
           return M_opponents_from_self;
       }
-    const PlayerPtrCont & getOpponentsFromSelf() const { return opponentsFromSelf(); }
 
     /*!
       \brief get teammates sorted by distance from ball
@@ -680,7 +670,6 @@ public:
       {
           return M_teammates_from_ball;
       }
-    const PlayerPtrCont & getTeammatesFromBall() const { return teammatesFromBall(); }
 
     /*!
       \brief get opponents sorted by distance from ball
@@ -691,7 +680,6 @@ public:
       {
           return M_opponents_from_ball;
       }
-    const PlayerPtrCont & getOpponentsFromBall() const { return opponentsFromBall(); }
 
     //////////////////////////////////////////////////////////
 
@@ -824,7 +812,6 @@ public:
       {
           return M_offside_line_x;
       }
-    const double & getOffsideLineX() const { return offsideLineX(); }
 
     /*!
       \brief get estimated defside line(offside line for opponent) x coodinate
@@ -835,7 +822,6 @@ public:
       {
           return M_defense_line_x;
       }
-    const double & getDefenseLineX() const { return defenseLineX(); }
 
     /*!
       \brief check if exist kickable teammate
@@ -941,7 +927,7 @@ public:
       \brief get uniform number of heared pass receiver
       \return uniform number
     */
-    int getHeardReceiverNumber() const
+    int heardReceiverNumber() const
       {
           return M_heard_receiver_number;
       }
@@ -951,7 +937,7 @@ public:
       \return const reference to heared position object
     */
     const
-    Vector2D & getHeardReceivePos() const
+    Vector2D & heardReceivePos() const
       {
           return M_heard_receive_pos;
       }
@@ -961,19 +947,19 @@ public:
       \return const reference to game time
     */
     const
-    GameTime & getHeardPassTime() const
+    GameTime & heardPassTime() const
       {
           return M_heard_pass_time;
       }
 
-    const 
-    GameTime & getHeardWaitRequestTime() const
+    const
+    GameTime & heardWaitRequestTime() const
       {
           return M_heard_wait_request_time;
       }
 
-    const 
-    GameTime & getHeardAttackRequestTime() const
+    const
+    GameTime & heardAttackRequestTime() const
       {
           return M_heard_attack_request_time;
       }
