@@ -33,7 +33,7 @@
 #define RCSC_RCG_UTIL_H
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
 #ifdef HAVE_NETINET_IN_H
